Search the Genotype-Phenotype Map
search_gpmap.RdSearch the GP Map for Traits, Genes or Variants
Value
A dataframe containing the search results with the following columns:
type: the type of the search result: "original_variant", "proxy_variant", "trait", "gene"
name: the name of the search result
type_id: the type_id of the search result. This is the internal id in which the data can be accessed.
call: the call to get the search result: "variant(type_id)", "trait(type_id)", "gene(type_id)"
info: a string containing informaiton about the search result, which may include:
Extractions: the number of extractions
Colocalisation Groups: the number of colocalisation groups
Colocalisation Studies: the number of colocalisation studies
Rare Results: the number of rare results
Rsquared: the rsquared of the proxy variant compared to the original variant